@@ -17,8 +17,8 @@ from .sym import sym
 SSH_MAN = """
      ssh [-AaCfGgKkMNnqsTtVvXxYy] [-B bind_interface] [-b bind_address] [-c cipher_spec]
          [-D [bind_address:]port] [-E log_file] [-e escape_char] [-F configfile] [-I pkcs11]
-         [-i identity_file] [-J destination] [-L address] [-l login_name] [-m mac_spec] [-O ctl_cmd]
-         [-o option] [-p port] [-Q query_option] [-R address] [-S ctl_path] [-W host:port]
+         [-i identity_file] [-J jump_destination] [-L address] [-l login_name] [-m mac_spec] [-O ctl_cmd]
+         [-o option] [-Q query_option] [-R address] [-S ctl_path] [-W host:port]
          [-w local_tun[:remote_tun]] destination [command]
 """
 
@@ -55,7 +55,6 @@ SSH_OPTS = list(
             "HostName",
             "VerifyHostKeyDNS",
             "UsePrivilegedPort",
-            "Port",
             "AddressFamily",
             "RemoteCommand",
             "HostKeyAlgorithms",
@@ -187,10 +186,10 @@ def use_interactive_ssm(is_a_tty: bool, command: Sequence[str], args: Dict) -> b
     },
 )
 @resource_argument
-@ssh_options
 @click.option("-p", "--port", default=22, type=int, show_default=True)
 @click.argument("destination", required=False)
 @click.argument("command", nargs=-1, required=False)
+@ssh_options
 @click.make_pass_decorator(GlobalOptions)
 @command_require_bins("aws", "session-manager-plugin", "ssh")
 @require_login
@@ -227,6 +226,7 @@ def ssh(
         return
 
     client = SAMLClientFactory.create_saml_client(resource, options)
+    client.send_analytics_event()
 
     client.dprint(f"ssh: args={ssh_args}")
     instance = get_ec2_client(client).load_instance_by_alias(destination)
