@@ -1,4 +1,3 @@
-import os
 import shlex
 import subprocess
 import sys
@@ -12,6 +11,8 @@ import click
 from sentry_sdk.api import configure_scope
 from sentry_sdk.hub import init as sentry_init
 
+from sym.cli.helpers.util import is_prod_mode
+
 from .errors import (
     CliError,
     ErrorPatterns,
@@ -36,10 +37,6 @@ from .saml_clients.saml_client_factory import SAMLClientFactory
 F = TypeVar("F", bound=Callable[..., Any])
 
 
-def is_prod_mode():
-    return os.getenv("SENTRY_ENVIRONMENT") != "development" and os.getenv("CI") != "true"
-
-
 def run_subprocess(
     func: Callable[..., Iterator[Sequence[Argument]]]
 ) -> Callable[..., Optional[Sequence[Optional[str]]]]:
